# `FoveaTorch` 👀🔥 <a href="https://bucket.ballarin.cc/serve/img/foveatorch_dalle2.png"><img src="https://bucket.ballarin.cc/serve/img/foveatorch_dalle2.png" align="right" height="139" /></a>

Differentiable foveated vision for Deep Learning methods

---

### References
- [J.S. Perry and W.S. Geisler, "Gaze-contingent real-time simulation of arbitrary visual fields", IS&T/SPIE Electronic Imaging, 2002](https://sci-hub.ru/10.1117/12.469554)
- [M. Jiang, S. Huang, J. Duan and Q. Zhao, "SALICON: Saliency in Context", IEEE Conference on Computer Vision and Pattern Recognition, 2015](https://sci-hub.ru/10.1109/CVPR.2015.7298710)
- [Zhibo Yang, "Image_Foveation_Python: Python implementation of image retina transformation"](https://github.com/ouyangzhibo/Image_Foveation_Python)
